@@ -186,10 +186,10 @@ function checkAnswer() {
     if(validateAnswer(parseInt(items.numpad.answer))) {
         items.score.currentSubLevel++
         items.score.playWinAnimation()
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav")
+        items.goodAnswerSound.play()
     } else {
         items.errorRectangle.startAnimation()
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav")
+        items.badAnswerSound.play()
     }
 }
 
