@@ -78,7 +78,7 @@ function initLevel() {
 function goodAnswer() {
     items.score.currentSubLevel++
     items.score.playWinAnimation()
-    items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+    items.winSound.play()
 }
 
 function nextLevel() {
