@@ -26,18 +26,13 @@ var mode
 
 function start(items_, dataset_) {
     items = items_
-    dataset = dataset_.get()
+    dataset = dataset_
     numberOfLevel = dataset.length
     items.currentLevel = Core.getInitialLevel(numberOfLevel)
 
-    var currentLocale = Qt.locale(GCompris.ApplicationInfo.getVoicesLocale(GCompris.ApplicationSettings.locale))
-    // First day of the week is either Saturday, Sunday or Monday depending on the country
-    if(currentLocale.firstDayOfWeek == Qml.Locale.Monday) {
+    if(Qt.locale(GCompris.ApplicationSettings.locale).firstDayOfWeek == Qml.Locale.Monday) {
         items.daysOfTheWeekModel.move(0, items.daysOfTheWeekModel.count - 1, 1)
     }
-    else if(currentLocale.firstDayOfWeek == Qml.Locale.Saturday) {
-        items.daysOfTheWeekModel.move(items.daysOfTheWeekModel.count - 1, 0, 1)
-    }
     initLevel();
 }
 
@@ -100,11 +95,11 @@ function updateScore(isCorrectAnswer) {
         items.okButtonParticles.burst(20)
         items.score.currentSubLevel++;
         items.score.playWinAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+        items.goodAnswerSound.play();
     }
     else {
         items.errorRectangle.startAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
+        items.badAnswerSound.play();
     }
 }
 
