@@ -27,7 +27,6 @@ var questions;
 var answers;
 var items;
 var mode;
-var locale;
 
 function start(_items, _mode)
 {
@@ -37,8 +36,9 @@ function start(_items, _mode)
     mode = _mode;
 
     // register the voices for the locale
-    locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
+    var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
     GCompris.DownloadManager.updateResource(GCompris.GCompris.VOICES, {"locale": locale})
+
     loadLevels();
     items.score.currentSubLevel = 0;
     numberOfLevel = levels.length;
@@ -65,6 +65,7 @@ function validateLevels(levels)
 function loadLevels()
 {
     var ret;
+    var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
     var filename = GCompris.ApplicationInfo.getLocaleFilePath(url + "levels-" + locale + ".json");
     levels = items.parser.parseFromUrl(filename);
     if (levels == null) {
@@ -125,42 +126,31 @@ function initLevel() {
         }
     }
 
+    var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale);
     currentLetter = questions.split("|")[items.score.currentSubLevel];
-    // Maybe we will display it if sound fails
-    items.questionItem.text = currentLetter;
     if (GCompris.ApplicationSettings.isAudioVoicesEnabled &&
             GCompris.DownloadManager.haveLocalResource(
                 GCompris.DownloadManager.getVoicesResourceForLocale(locale))) {
-        appendVoices(locale);
+        items.audioVoices.append(GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/"+locale+"/misc/click_on_letter.$CA"))
+        items.audioVoices.silence(100)
+        playLetter(currentLetter)
+        items.questionItem.visible = false
+        items.repeatItem.visible = true
     } else {
         // no sound -> show question
         items.questionItem.visible = true;
         items.repeatItem.visible = false
     }
+    // Maybe we will display it if sound fails
+    items.questionItem.text = currentLetter;
+
     items.buttonsBlocked = false;
 }
 
-function appendVoices() {
-    if(GCompris.DownloadManager.areVoicesRegistered(items.locale)) {
-        items.audioVoices.append(GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/"+locale+"/misc/click_on_letter.$CA"));
-        items.audioVoices.silence(100);
-        playLetter(currentLetter);
-    } else {
-        items.voiceTimer.start();
-    }
-}
-
 function playLetter(letter) {
-    var letterAudio = GCompris.ApplicationInfo.getAudioFilePath(
-        "voices-$CA/"+locale+"/alphabet/" + Core.getSoundFilenamForChar(letter))
-     if(items.audioVoices.append(letterAudio)) {
-         items.questionItem.visible = false
-         items.repeatItem.visible = true
-    } else {
-        // no sound -> show question
-        items.questionItem.visible = true;
-        items.repeatItem.visible = false
-    }
+    var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
+    items.audioVoices.append(GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/"+locale+"/alphabet/"
+                                                                       + Core.getSoundFilenamForChar(letter)))
 }
 
 function nextLevel() {
@@ -193,7 +183,7 @@ function checkAnswer(index) {
     if (modelEntry.letter === currentLetter) {
         items.score.currentSubLevel++;
         items.score.playWinAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+        items.winSound.play();
         return true
     } else {
         return false
