@@ -173,11 +173,11 @@ function checkAnswer() {
                     && items.currentS === items.targetS) {
         items.score.currentSubLevel++;
         items.score.playWinAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+        items.goodAnswerSound.play();
     }
     else {
         items.errorRectangle.startAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
+        items.badAnswerSound.play();
     }
 }
 
