@@ -111,11 +111,11 @@ function goodAnswer() {
     items.buttonsBlocked = true;
     items.score.currentSubLevel++;
     items.score.playWinAnimation();
-    items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+    items.goodAnswerSound.play();
 }
 
 function badAnswer() {
     items.buttonsBlocked = true;
     items.errorRectangle.startAnimation();
-    items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
+    items.badAnswerSound.play();
 }
