@@ -122,11 +122,11 @@ function checkAnswer() {
     if(items.answer === items.question) {
         ++items.score.currentSubLevel;
         items.score.playWinAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+        items.goodAnswerSound.play();
         removeLastQuestion();
     } else {
         items.errorRectangle.startAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
+        items.badAnswerSound.play();
     }
 }
 
