@@ -18,12 +18,12 @@ var url = "qrc:/gcompris/src/activities/missing-letter/resource/"
 var langUrl = "qrc:/gcompris/src/activities/lang/resource/";
 
 var items
-var currentLevel
 var numberOfLevel
 
 var questions
 var dataset
 var lessons
+var currentQuestion
 
 // Do not propose these letter in the choices
 var ignoreLetters = '[ ,;:\\-\u0027]'
@@ -34,15 +34,13 @@ function init(items_) {
 }
 
 function start() {
-    currentLevel = 0
-
     var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
 
     // register the voices for the locale
-    GCompris.DownloadManager.updateResource(GCompris.DownloadManager.getVoicesResourceForLocale(locale))
+    GCompris.DownloadManager.updateResource(GCompris.GCompris.VOICES, {"locale": locale})
 
     dataset = Lang.load(items.parser, langUrl,
-                        GCompris.ApplicationSettings.wordset ? "words.json" : "words_sample.json",
+                        GCompris.ApplicationSettings.useExternalWordset() ? "words.json" : "words_sample.json",
                         "content-"+ locale +".json")
 
     // If dataset is empty, we try to load from short locale
@@ -57,7 +55,7 @@ function start() {
             localeShort = locale;
         }
         dataset = Lang.load(items.parser, langUrl,
-                            GCompris.ApplicationSettings.wordset ? "words.json" : "words_sample.json",
+                            GCompris.ApplicationSettings.useExternalWordset() ? "words.json" : "words_sample.json",
                             "content-"+localeShort+ ".json")
     }
 
@@ -66,7 +64,7 @@ function start() {
         // English fallback
         items.background.englishFallback = true
         dataset = Lang.load(items.parser, langUrl,
-                            GCompris.ApplicationSettings.wordset ? "words.json" : "words_sample.json",
+                            GCompris.ApplicationSettings.useExternalWordset() ? "words.json" : "words_sample.json",
                             "content-en.json")
     } else {
         items.background.englishFallback = false
@@ -75,6 +73,7 @@ function start() {
     lessons = Lang.getAllLessons(dataset)
     questions = initDataset()
     numberOfLevel = questions.length
+    items.currentLevel = Core.getInitialLevel(numberOfLevel)
     initLevel()
 }
 
@@ -180,62 +179,57 @@ function stop() {
 
 function initLevel() {
     items.questionAnim.stop()
-    items.bar.level = currentLevel + 1
-    items.score.currentSubLevel = 1
-    items.score.numberOfSubLevels = questions[currentLevel].length
+    items.score.currentSubLevel = 0
+    items.score.numberOfSubLevels = questions[items.currentLevel].length
     showQuestion()
 }
 
 function getCurrentQuestion() {
-    return questions[currentLevel][items.score.currentSubLevel - 1]
+    return questions[items.currentLevel][items.score.currentSubLevel]
 }
 
 function showQuestion() {
-    var question = getCurrentQuestion()
+    currentQuestion = getCurrentQuestion()
 
-    playWord(question.voice)
-    items.answer = question.answer
-    items.answers.model = question.choices
-    items.questionText.text = question.maskedQuestion
-    items.questionImage.source = question.image
+    playWord(currentQuestion.voice)
+    items.answer = currentQuestion.answer
+    items.answers.model = currentQuestion.choices
+    items.questionText.text = currentQuestion.maskedQuestion
+    items.questionImage.source = currentQuestion.image
     items.isGoodAnswer = false
     items.buttonsBlocked = false
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0
-    }
+    items.score.stopWinAnimation()
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function nextSubLevel() {
-    var question = getCurrentQuestion()
-
-    if(items.score.currentSubLevel >= questions[currentLevel].length) {
+    if(items.score.currentSubLevel >= items.score.numberOfSubLevels) {
         items.bonus.good('flower')
         return
     }
-    items.score.currentSubLevel ++;
     showQuestion()
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1
-    }
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function showAnswer() {
-    var question = getCurrentQuestion()
-    playLetter(question.answer)
+    playLetter(currentQuestion.answer)
     items.isGoodAnswer = true
-    items.questionText.text = question.clearQuestion
+    items.questionText.text = currentQuestion.clearQuestion
 }
 
 function playLetter(letter) {
     var locale = GCompris.ApplicationInfo.getVoicesLocale(items.locale)
+    items.audioVoices.stop()
+    items.audioVoices.clearQueue()
     items.audioVoices.append(GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/"+locale+"/alphabet/" +
                              Core.getSoundFilenamForChar(letter)))
 }
