@@ -66,6 +66,7 @@ function getCoinCount (pocket) {
 function initLevel() {
     items.answerModel.clear()
     items.pocketModel.clear()
+    items.errorRectangle.resetState()
 
     var data = dataset[items.currentLevel]
     var pocket = Core.shuffle(data.pocket)
@@ -122,12 +123,6 @@ function initLevel() {
             }
             priceTotal += cents
             price += cents
-            // For the last item, make sure we are not above the maximum
-            if(priceTotal > data.maxPrice && i == data.numberOfItem - 1) {
-                var diff = priceTotal - data.maxPrice
-                priceTotal = data.maxPrice
-                price -= diff
-            }
         }
 
         var priceText = Core.convertNumberToLocaleCurrencyString(Number(price), locale)
@@ -184,6 +179,8 @@ function initLevel() {
     items.itemIndex = -1
     items.selectedArea = items.pocket
 
+    //Enable controls
+    items.buttonsBlocked = false
 }
 
 // Given a price return a random object
@@ -206,35 +203,45 @@ function checkAnswer() {
 
     paid = paid.toFixed(2)
 
+    items.buttonsBlocked = true;
+
     if(!backMode) {
         if(paid === priceTotal.toFixed(2))
             items.bonus.good("flower")
+        else if(items.mode === 2) {
+            items.errorRectangle.startAnimation();
+            items.badAnswerSound.play();
+        }
     } else {
         if(paid === (dataset[items.currentLevel].paid - priceTotal).toFixed(2))
             items.bonus.good("flower")
+        else if(items.mode === 2) {
+            items.errorRectangle.startAnimation();
+            items.badAnswerSound.play();
+        }
     }
 }
 
 function pay(index) {
-    items.audioEffects.play(url + "money1.wav")
+    items.paySound.play()
     // Add it to the anwser
     items.answerModel.append(items.pocketModel.get(index))
 
     // Remove it from the pocket
     items.pocketModel.remove(index, 1)
-
-    checkAnswer()
+    if(items.mode === 1)
+        checkAnswer()
 }
 
 function unpay(index) {
-    items.audioEffects.play(url + "money2.wav")
+    items.unpaySound.play()
     // Add it to the pocket
     items.pocketModel.append(items.answerModel.get(index))
 
     // Remove it from the Answer
     items.answerModel.remove(index, 1)
-
-    checkAnswer()
+    if(items.mode === 1)
+        checkAnswer()
 }
 
 function nextLevel() {
