@@ -64,7 +64,7 @@ function answerSelected(index) {
     if(!items.selectedItem)
         return
 
-    items.audioEffects.play("qrc:/gcompris/src/activities/redraw/resource/brush.wav")
+    items.brushSound.play()
     items.answerModel.set(index, { "imgUrl": items.selectedItem })
 
     for(var i=0; i < questionModel.length; i++) {
