@@ -10,8 +10,8 @@
  */
 .pragma library
 .import QtQuick 2.12 as Quick
+.import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel = 0
 var numberOfLevel = 9
 var items
 
@@ -19,7 +19,7 @@ var url = "qrc:/gcompris/src/activities/penalty/resource/"
 
 function start(items_) {
     items = items_
-    currentLevel = 0
+    items.currentLevel = Core.getInitialLevel(numberOfLevel)
     initLevel()
 }
 
@@ -27,16 +27,15 @@ function stop() {
 }
 
 function initLevel() {
-    items.bar.level = currentLevel + 1
-    if(currentLevel === 0) items.duration = 1000
-    else if(currentLevel === 1) items.duration = 800
-    else if(currentLevel === 2) items.duration = 700
-    else if(currentLevel === 3) items.duration = 600
-    else if(currentLevel === 4) items.duration = 500
-    else if(currentLevel === 5) items.duration = 400
-    else if(currentLevel === 6) items.duration = 350
-    else if(currentLevel === 7) items.duration = 300
-    else if(currentLevel === 8) items.duration = 250
+    if(items.currentLevel === 0) items.duration = 1000
+    else if(items.currentLevel === 1) items.duration = 800
+    else if(items.currentLevel === 2) items.duration = 700
+    else if(items.currentLevel === 3) items.duration = 600
+    else if(items.currentLevel === 4) items.duration = 500
+    else if(items.currentLevel === 5) items.duration = 400
+    else if(items.currentLevel === 6) items.duration = 350
+    else if(items.currentLevel === 7) items.duration = 300
+    else if(items.currentLevel === 8) items.duration = 250
 
     resetLevel()
 }
@@ -50,15 +49,11 @@ function resetLevel() {
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0
-    }
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1
-    }
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
