@@ -72,6 +72,10 @@ function initLevel() {
     items.movePlaneTimer.stop();
     items.cloudCreation.stop()
 
+    if(dataset[items.currentLevel].toolTipText) {
+        items.toolTipText = dataset[items.currentLevel].toolTipText
+    }
+
     items.score.message = dataset[items.currentLevel].data[currentSubLevel]
     items.score.visible = dataset[items.currentLevel].showNext
 
@@ -303,7 +307,7 @@ function handleCollisionsWithCloud() {
                 } else {
                     /* Touched the wrong cloud */
                     if(!cloud.touched)
-                        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav")
+                        items.crashSound.play()
                     cloud.touch()
                 }
                 break;
