@@ -70,11 +70,11 @@ function verifyAnswer() {
     if(items.selectedPosition === items.checkState) {
         items.score.currentSubLevel += 1;
         items.score.playWinAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+        items.goodAnswerSound.play();
     }
     else {
         items.errorRectangle.startAnimation();
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
+        items.badAnswerSound.play();
     }
 }
 
