@@ -12,7 +12,6 @@
 .import "Dataset.js" as Dataset
 .import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel = 0
 var numberOfLevel
 var items
 var dataset
@@ -24,7 +23,7 @@ var allQuestions = []
 
 function start(items_) {
     items = items_
-    currentLevel = 0
+    items.currentLevel = 0
     dataset = Dataset.get()
 
     for(var i = 0;  i < dataset.length; ++i) {
@@ -44,17 +43,18 @@ function stop() {
 
 function initLevel() {
     currentSubLevel = 0
-    items.bar.level = currentLevel + 1
+    items.restartAssessmentMessage = false
     items.mainQuizScreen.score.numberOfSubLevels = currentPlanetLevels.length
     Core.shuffle(currentPlanetLevels)
     nextSubLevel(false)
 }
 
 function nextSubLevel(isAssessmentMode) {
-    items.mainQuizScreen.score.currentSubLevel = currentSubLevel
+    items.restartAssessmentMessage = false
     var optionListShuffle = []
 
     if(!isAssessmentMode) {
+        items.mainQuizScreen.score.currentSubLevel = currentSubLevel
         items.mainQuizScreen.closenessMeterValue = 0
 
         if(currentSubLevel+1 > items.mainQuizScreen.score.numberOfSubLevels) {
@@ -72,7 +72,8 @@ function nextSubLevel(isAssessmentMode) {
             }
         }
     }
-    else if(!items.mainQuizScreen.restartAssessmentMessage.visible) {
+    else if(items.mainQuizScreen.score.currentSubLevel < items.mainQuizScreen.score.numberOfSubLevels) {
+        items.mainQuizScreen.score.currentSubLevel = currentSubLevel + 1
         items.mainQuizScreen.question = assessmentModeQuestions[0].question
         for(var i = 0 ; i < 4 ; i ++) {
             optionListShuffle.push({
@@ -81,6 +82,10 @@ function nextSubLevel(isAssessmentMode) {
             });
         }
     }
+    else {
+        items.restartAssessmentMessage = true
+        return
+    }
 
     items.mainQuizScreen.closenessMeter.stopAnimations()
 
@@ -91,7 +96,8 @@ function nextSubLevel(isAssessmentMode) {
         for(var i = 0 ; i < optionListShuffle.length ; i ++)
             items.mainQuizScreen.optionListModel.append(optionListShuffle[i])
 
-        currentSubLevel++
+        if(isAssessmentMode)
+            currentSubLevel++
     }
 }
 
@@ -104,6 +110,7 @@ function startAssessmentMode() {
     items.solarSystemVisible = false
     items.quizScreenVisible = true
     items.mainQuizScreen.numberOfCorrectAnswers = 0
+    items.mainQuizScreen.score.currentSubLevel = 0
     items.mainQuizScreen.score.numberOfSubLevels = 20
     currentSubLevel = 0
     assessmentModeQuestions = []
@@ -123,9 +130,7 @@ function appendAndAddQuestion() {
     var incorrectAnsweredQuestion = assessmentModeQuestions.shift()
     assessmentModeQuestions.push(incorrectAnsweredQuestion)
 
-    if(items.mainQuizScreen.score.numberOfSubLevels == 24)
-        items.mainQuizScreen.score.numberOfSubLevels++
-    else if(items.mainQuizScreen.score.numberOfSubLevels < 24) {
+    if(items.mainQuizScreen.score.numberOfSubLevels < 24) {
         assessmentModeQuestions.push(allQuestions[items.mainQuizScreen.score.numberOfSubLevels])
         items.mainQuizScreen.score.numberOfSubLevels += 2
     }
@@ -136,7 +141,7 @@ function appendAndAddQuestion() {
 }
 
 function showQuizScreen(index) {
-    currentLevel = 0
+    items.currentLevel = 0
     indexOfSelectedPlanet = index
 
     items.solarSystemVisible = false
@@ -154,9 +159,7 @@ function showQuizScreen(index) {
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0
-    }
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     if(!items.assessmentMode)
         initLevel()
     else
@@ -164,8 +167,6 @@ function nextLevel() {
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1
-    }
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
