@@ -273,9 +273,9 @@ function checkAnswer() {
         items.buttonsBlocked = true;
         items.score.currentSubLevel++
         items.score.playWinAnimation()
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav")
+        items.goodAnswerSound.play()
     }
     else {
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav")
+        items.badAnswerSound.play()
     }
 }
