@@ -44,17 +44,17 @@ public:
     void setCurrentActivity(ActivityInfo *currentActivity);
     ActivityInfo *getCurrentActivity() const;
     void menuTreeAppend(ActivityInfo *menu);
-    void menuTreeAppend(QQmlEngine *engine,
-                        const QDir &menuDir, const QString &menuFile);
     void sortByDifficultyThenName(bool emitChanged = true);
     QVariantList allCharacters();
 
-    static void setStartingActivity(const QString &startingActivity, int startingLevel)
+    void setStartingActivity(const QString &startingActivity, int startingLevel)
     {
         m_startingActivity = startingActivity;
         m_startingLevel = startingLevel;
     }
 
+    void initialize(QQmlEngine *engine);
+
 protected:
     static ActivityInfoTree *m_instance;
 
@@ -88,9 +88,8 @@ private:
     QList<ActivityInfo *> m_menuTree;
     ActivityInfo *m_rootMenu;
     ActivityInfo *m_currentActivity;
-    QVariantList m_keyboardCharacters;
-    static QString m_startingActivity;
-    static int m_startingLevel;
+    QString m_startingActivity;
+    int m_startingLevel = -1;
 
     static QList<ActivityInfo>::size_type menuTreeCount(QQmlListProperty<ActivityInfo> *property);
     static ActivityInfo *menuTreeAt(QQmlListProperty<ActivityInfo> *property, QList<ActivityInfo>::size_type index);
@@ -98,7 +97,7 @@ private:
     static QList<ActivityInfo>::size_type menuTreeFullCount(QQmlListProperty<ActivityInfo> *property);
     static ActivityInfo *menuTreeFullAt(QQmlListProperty<ActivityInfo> *property, QList<ActivityInfo>::size_type index);
 
-    static QStringList getActivityList();
+    QStringList getActivityList();
 
 public:
     static void registerResources();
