@@ -18,6 +18,7 @@
 
 #include <QObject>
 #include <QSslSocket>
+#include <QTranslator>
 
 class QQmlEngine;
 class QQuickWindow;
@@ -133,11 +134,11 @@ class ApplicationInfo : public QObject
     Q_PROPERTY(bool isDownloadAllowed READ isDownloadAllowed CONSTANT)
 
     /**
-     * Whether the application is currently using OpenGL or not.
+     * Whether the application is currently using software renderer or not.
      *
-     * Use to deactivate some effects if OpenGL not used.
+     * Use to deactivate some effects if software renderer used.
      */
-    Q_PROPERTY(bool useOpenGL READ useOpenGL WRITE setUseOpenGL NOTIFY useOpenGLChanged)
+    Q_PROPERTY(bool useSoftwareRenderer READ useSoftwareRenderer WRITE setUseSoftwareRenderer NOTIFY useSoftwareRendererChanged)
 
     /**
      * Whether Box2D is installed or not.
@@ -274,17 +275,25 @@ public:
     {
         return localeShort(ApplicationSettings::getInstance()->locale());
     }
+
+    /**
+     * Switch the locale in GCompris to the new one.
+     * The locale will be fetched from ApplicationSettings if not passed in parameter
+     */
+    void switchLocale();
+    void switchLocale(const QString &locale);
+
     static QString GCVersion() { return VERSION; }
     static int GCVersionCode() { return VERSION_CODE; }
     static QString QTVersion() { return qVersion(); }
     static QString OpenSSLVersion() { return QSslSocket::sslLibraryVersionString(); }
     static QString CompressedAudio() { return COMPRESSED_AUDIO; }
     static bool isDownloadAllowed() { return QString(DOWNLOAD_ALLOWED) == "ON"; }
-    bool useOpenGL() const { return m_useOpenGL; }
-    void setUseOpenGL(bool useOpenGL) { m_useOpenGL = useOpenGL; }
+    bool useSoftwareRenderer() const { return m_useSoftwareRenderer; }
+    void setUseSoftwareRenderer(bool useSoftwareRenderer) { m_useSoftwareRenderer = useSoftwareRenderer; }
 
     bool isBox2DInstalled() const { return m_isBox2DInstalled; }
-    void setBox2DInstalled(const QQmlEngine &engine);
+    void setBox2DInstalled(QQmlEngine &engine);
 
     /**
      * Returns the native screen orientation.
@@ -431,16 +440,18 @@ Q_SIGNALS:
     void fontRatioChanged();
     void applicationSettingsChanged();
     void fullscreenChanged();
-    void useOpenGLChanged();
+    void useSoftwareRendererChanged();
     void isBox2DInstalledChanged();
 
 private:
     static ApplicationInfo *m_instance;
+    QQmlEngine *m_engine { nullptr };
+    QTranslator m_translator;
     int m_applicationWidth;
     Platform m_platform;
     bool m_isPortraitMode;
     bool m_isMobile;
-    bool m_useOpenGL;
+    bool m_useSoftwareRenderer;
     bool m_isBox2DInstalled;
     qreal m_ratio;
     qreal m_fontRatio;
@@ -451,6 +462,10 @@ private:
     QStringList m_backgroundMusicFromRcc;
 
     static QQuickWindow *m_window;
+
+    bool loadAndroidTranslation(const QString &locale);
+    bool isSupportedLocale(const QString &locale);
+    QString loadTranslation(const QString &requestedLocale);
 };
 
 #endif // APPLICATIONINFO_H
