@@ -6,12 +6,12 @@
 #
 #   SPDX-License-Identifier: GPL-3.0-or-later
 
-Qt5_BaseDIR=~/Qt/5.12.12
+Qt6_BaseDIR=~/Qt6/6.6.3
 export ANDROID_NDK_ROOT=$ANDROID_NDK
 
 if [ "$#" -eq 1 ]; then
-    Qt5_BaseDIR=$1
-    echo "Overriding Qt5_BaseDIR to ${Qt5_BaseDIR}"
+    Qt6_BaseDIR=$1
+    echo "Overriding Qt6_BaseDIR to ${Qt6_BaseDIR}"
 fi
 
 # The current version
@@ -39,18 +39,19 @@ f_cmake()
     if [ -f CMakeCache.txt ]
     then
 	make clean
-	rm CMakeCache.txt
-	rm cmake_install.cmake
-        rm Makefile
+	rm -f CMakeCache.txt
+	rm -f cmake_install.cmake
+        rm -f Makefile
         rm -rf CMakeFiles
     fi
 
-    cmake -DCMAKE_TOOLCHAIN_FILE=/usr/share/ECM/toolchain/Android.cmake \
-	  -DCMAKE_ANDROID_API=16 \
+    cmake -DCMAKE_TOOLCHAIN_FILE=${ANDROID_NDK}/build/cmake/android.toolchain.cmake \
+          -DCMAKE_ANDROID_API=26 \
+          -DANDROID_PLATFORM=26 \
 	  -DCMAKE_BUILD_TYPE=Release \
 	  -DANDROID_ABI=$1 \
-	  -DCMAKE_FIND_ROOT_PATH=${Qt5_BaseDIR}/${QtTarget}/lib/ \
-	  -DQt5_DIR=${Qt5_BaseDIR}/${QtTarget}/lib/cmake/Qt5 \
+	  -DCMAKE_FIND_ROOT_PATH=${Qt6_BaseDIR}/${QtTarget}/lib/ \
+	  -DCMAKE_PREFIX_PATH=${Qt6_BaseDIR}/${QtTarget}/lib/cmake/Qt6 \
 	  -Wno-dev \
 	  -DQML_BOX2D_MODULE=submodule \
 	  -DWITH_DOWNLOAD=$2 \
@@ -67,7 +68,7 @@ mkdir -p ${builddir}
 cd ${builddir}
 
 # Retrieve the Qt version
-if [[ $Qt5_BaseDIR =~ [0-9]+\.[0-9]+\.[0-9]+ ]]; then
+if [[ $Qt6_BaseDIR =~ [0-9]+\.[0-9]+\.[0-9]+ ]]; then
     version=${BASH_REMATCH[0]}
 fi
 n=${version//[!0-9]/ }
@@ -76,15 +77,8 @@ major=${a[0]}
 minor=${a[1]}
 patch=${a[2]}
 
-# If we use Qt > 5.14, we need to update some variables
-if [[ $minor -ge 14 ]]; then
-    echo "Using Qt5.14 or more";
-    cmake_extra_args="-DANDROID_BUILD_ABI_armeabi-v7a=ON"
-    QtTarget=android
-fi
-
 f_cmake armeabi-v7a ON OFF
-make -j 4
+make -j 16
 make apk_aligned_signed
 
 # Remove extra apk
