@@ -13,8 +13,8 @@ import glob
 import subprocess
 import xml.etree.ElementTree as ET
 
-from PyQt5.QtCore import QCoreApplication, QUrl
-from PyQt5.QtQml import qmlRegisterType, QQmlComponent, QQmlEngine
+from PySide6.QtCore import QCoreApplication, QUrl
+from PySide6.QtQml import qmlRegisterType, QQmlComponent, QQmlEngine
 import polib
 
 from python.ActivityInfo import ActivityInfo
@@ -165,7 +165,7 @@ def main(argv):
     changelog_qml = component.create()
 
     # List taken from the android list
-    for locale in ["en-US", "ar-AR", "az-AZ", "be", "ca", "cs-CZ", "de-DE", "el-GR", "en-GB", "es-ES", "eu-ES", "fi-FI", "fr-FR", "gl-ES", "he", "hr", "hu-HU", "id", "it-IT", "lt", "lv-LV", "mk-MK", "ml-IN", "nl-NL", "no-NO", "pl-PL", "pt-BR", "pt-PT", "ro", "ru-RU", "sk", "sl", "sq", "sv-SE", "tr-TR", "uk", "zh-CN", "zh-TW"]:
+    for locale in ["en-US", "ar-AR", "az-AZ", "be", "ca", "cs-CZ", "de-DE", "el-GR", "en-GB", "es-ES", "eu-ES", "fi-FI", "fr-FR", "gl-ES", "he", "hr", "hu-HU", "id", "it-IT", "ka-GE", "lt", "lv-LV", "mk-MK", "ml-IN", "nl-NL", "no-NO", "pl-PL", "pt-BR", "pt-PT", "ro", "ru-RU", "sa-IN", "sk", "sl", "sq", "sv-SE", "tr-TR", "uk", "zh-CN", "zh-TW"]:
         is_translation_ok = generate_files_for_locale(changelog_qml, locale)
         if not is_translation_ok and verbose:
             print(f"Error when generating files for {locale}")
