@@ -8,7 +8,6 @@ module.exports = {
     'mergeStyles',
     'inlineStyles',
     'minifyStyles',
-    'cleanupIDs',
     'removeUselessDefs',
     'convertColors',
     'removeUnknownsAndDefaults',
@@ -20,6 +19,8 @@ module.exports = {
     'moveElemsAttrsToGroup',
     'moveGroupAttrsToElems',
     'collapseGroups',
+    'convertPathData',
+    'convertTransform',
     'removeEmptyAttrs',
     'removeEmptyContainers',
     'removeUnusedNS',
